summaryrefslogtreecommitdiff
path: root/source3/rpc_server/srv_pipe_hnd.c
diff options
context:
space:
mode:
authorJeremy Allison <jra@samba.org>2001-03-03 05:27:26 +0000
committerJeremy Allison <jra@samba.org>2001-03-03 05:27:26 +0000
commit93169a1f34f180f8a469a25532792f23e55e6966 (patch)
treec8ffcb88093b74257b091dd6983a6b87798f4d4c /source3/rpc_server/srv_pipe_hnd.c
parente9f555e4bd0c778e40f9661562806fb52dc421d9 (diff)
downloadsamba-93169a1f34f180f8a469a25532792f23e55e6966.tar.gz
samba-93169a1f34f180f8a469a25532792f23e55e6966.tar.bz2
samba-93169a1f34f180f8a469a25532792f23e55e6966.zip
Roll back to using malloc/realloc on some of spoolss in head.
I'm having problems with talloc_realloc in the 2.2 branch and I want a stable reference. The only problem is this breaks the clean auto-generated code in *one* call in srv_spoolss.c (the rfnpcnex call). Jeremy. (This used to be commit 57a9340cbafa40f3a41e6c676c6f2477855fd799)
Diffstat (limited to 'source3/rpc_server/srv_pipe_hnd.c')
-rw-r--r--source3/rpc_server/srv_pipe_hnd.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/source3/rpc_server/srv_pipe_hnd.c b/source3/rpc_server/srv_pipe_hnd.c
index 3b60c78ade..eb369f22b4 100644
--- a/source3/rpc_server/srv_pipe_hnd.c
+++ b/source3/rpc_server/srv_pipe_hnd.c
@@ -397,10 +397,10 @@ authentication failed. Denying the request.\n", p->name));
}
/*
* Check the data length doesn't go over the 1Mb limit.
*/
- if(prs_data_size(&p->in_data.data) + data_len > 1024*1024) {
+ if(prs_data_size(&p->in_data.data) + data_len > 10*1024*1024) {
DEBUG(0,("process_request_pdu: rpc data buffer too large (%u) + (%u)\n",
(unsigned int)prs_data_size(&p->in_data.data), (unsigned int)data_len ));
set_incoming_fault(p);
@@ -397,10 +397,10 @@ authentication failed. Denying the request.\n", p->name));
}
/*
- * Check the data length doesn't go over the 1Mb limit.
+ * Check the data length doesn't go over the 10Mb limit.
*/